@@ -296,10 +296,26 @@ class SSHClient(object):
             f" {self.__ip}:{self.__port} | Begin to copy file from remote {remote_path} to local host {local_path}.")
         if os.path.isfile(local_path):
             subprocess.run(['rm', '-rf', local_path], capture_output=True, text=True)
-        self.__sftp.get(remote_path, local_path)
-        log.info(
-            f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
-        return True
+        for i in range(3):
+            log.info(f" {self.__ip}:{self.__port} | Try to copy file from remote {remote_path} to local host{local_path}, retry {i}.")
+            try:
+                self.__sftp.get(remote_path, local_path)
+                log.info(
+                    f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
+                return True
+            except OSError as e:
+                log.warning(
+                    f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error. err msg is {str(e)}")
+                self.reconnect()
+                self.__sftp = self.__ssh.open_sftp()
+            except Exception as e:
+                log.warning(
+                    f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
+        else:
+            log.error(
+                f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
+            return False
+
 
     @enter_and_leave_function
     def ssh_is_active(self):
